Hardware - Heros Devices 0.7.1 documentation

Skip to content
Back to top
View this page

# Hardware

Ftdi
FT232H
beta
General Purpose USB to GPIO, SPI, I2C
Analog Devices
DS18B20
beta
Temperature Sensor -55°C to 125°C
Adafruit

https://www.adafruit.com/product/2264

The implementation https://github.com/eblot/pyftdi supports simultaneous use of SPI and GPIO pins. Unfortunately it is based on using bitmasks for everything.

FT232H
beta
General Purpose USB to GPIO, SPI, I2C
Gamma Vacuum
SPC (Ethernet)
beta
Ion getter pump controlled by digitel SPCe controller
SPC (Serial)
beta
Ion getter pump controlled by digitel SPCe controller
Hamamatsu Photonics
DCAM Camera
beta
Camera compatible with the Hamamatsu DCAM API
HighFinesse GmbH
WSx
beta
First generation WS wavelength meter with optional 8 channel switch
IDS Imaging Development Systems

IDS is an industrial camera manufacturer and offers high-performance area scan cameras with USB or GigE interfaces as well as 3D cameras with a wide range of sensors and variants.

IDS Peak Camera
beta
Camera compatible with the IDS Peak driver
Pico Technology
6000 Series
beta
Deep memory MSO USB oscilloscope
Rigol Technologies
RigolDSA
beta
DSA series spectrum analyzer
SAES Getters
NEXTorr
beta
Non-evaporable getter pump controlled by NEG Power Multi-controller
Santec Corporation
SLM-200
beta
120Hz Full-HD LCOS SLM
Sinara Open Hardware Project
Booster
alpha
Modular 8-channel RF power amplifier
Stanford Research Systems (SRS)
PTC10
beta
Programmable temperature controller
Teledyne Technologies
Kinetix
beta
High speed sCMOS camera
PVCam Camera
beta
Generic PVCam compatible camera
Texas Instruments
ADS1256
alpha
24-Bit, 30kSPS, 8-Ch Delta-Sigma ADC
Toptica Photonics
BoosTAPro
beta
High-Power Tapered Laser Amplifier
DLPro
beta
Tunable external cavity diode lasers for cooling and controlling all atoms and ions
TAPro
beta
Tapered Amplifier Laser System
TASHGPro
alpha
High-power, tunable, frequency-doubled diode laser
Windfreak Technologies, LLC
SynthUSBII
stable
34.4MHz - 4.4GHz USB RF Signal Generator
SynthUSBIII
stable
12.5MHz - 6.4GHz USB RF Signal Generator
Generic
GPIO Input
beta
Generic GPIO based standard linux kernel interface
GPIO Output
beta
Generic GPIO based standard linux kernel interface